<?php

namespace Bcscoder\Venue\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Bcscoder\Venue\Http\Requests\VenueAdminRequest;
use Bcscoder\Venue\Interfaces\VenueRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class VenueAdminController extends AdminController
{
    /**
     * Initialize venue controller.
     *
     * @param type VenueRepositoryInterface $venue
     *
     * @return type
     */
    public function __construct(VenueRepositoryInterface $venue)
    {
        $this->model = $venue;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(VenueAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('venue.venue.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('venue::venue.names').' :: ');

        return $this->theme->of('venue::admin.venue.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(VenueAdminRequest $request, $id)
    {
        $venue = $this->model->find($id);

        if (empty($venue)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('venue::admin.venue.new');
        }

        if ($request->wantsJson()) {
            return $venue;
        }

        Former::populate($venue);

        return view('venue::admin.venue.show', compact('venue'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(VenueAdminRequest $request)
    {
        $venue = $this->model->findOrNew(0);
        Former::populate($venue);

        return view('venue::admin.venue.create', compact('venue'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(VenueAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $venue = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('venue::venue.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(VenueAdminRequest $request, $id)
    {
        $venue = $this->model->find($id);

        Former::populate($venue);

        return view('venue::admin.venue.edit', compact('venue'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(VenueAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $venue = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('venue::venue.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(VenueAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('venue::venue.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
